pytilities.descriptors.bounddescriptor — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.descriptors »

# pytilities.descriptors.bounddescriptor

`pytilities.descriptors.bounddescriptor.` `BoundDescriptor`

  A descriptor with an object bound to it.

  It’s like bound methods, but more general.

  Instead of using the passed obj, it will use its stored obj as instance for the descriptor.

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.descriptors »